summaryrefslogtreecommitdiffstats
path: root/src/engine/SCons/Platform/win32.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/engine/SCons/Platform/win32.py')
-rw-r--r--src/engine/SCons/Platform/win32.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/engine/SCons/Platform/win32.py b/src/engine/SCons/Platform/win32.py
index 79d73b3..890b925 100644
--- a/src/engine/SCons/Platform/win32.py
+++ b/src/engine/SCons/Platform/win32.py
@@ -192,7 +192,7 @@ def escape(x):
def get_system_root():
# A resonable default if we can't read the registry
try:
- val = os.environ['SYSTEMROOT']
+ val = os.environ['SystemRoot']
except KeyError:
val = "C:/WINDOWS"
pass
@@ -268,8 +268,8 @@ def generate(env):
# contain an ENV and a PATH.
if not cmd_interp:
systemroot = r'C:\Windows'
- if os.environ.has_key('SYSTEMROOT'):
- systemroot = os.environ['SYSTEMROOT']
+ if os.environ.has_key('SystemRoot'):
+ systemroot = os.environ['SystemRoot']
tmp_path = systemroot + os.pathsep + \
os.path.join(systemroot,'System32')
tmp_pathext = '.com;.exe;.bat;.cmd'
@@ -291,12 +291,12 @@ def generate(env):
# Import things from the external environment to the construction
# environment's ENV. This is a potential slippery slope, because we
# *don't* want to make builds dependent on the user's environment by
# default. We're doing this for SYSTEMROOT, though, because it's
# needed for anything that uses sockets, and seldom changes, and
# for SYSTEMDRIVE because it's related.
#
# Weigh the impact carefully before adding other variables to this list.
- import_env = [ 'SYSTEMDRIVE', 'SYSTEMROOT', 'TEMP', 'TMP' ]
+ import_env = [ 'SystemDrive', 'SystemRoot', 'TEMP', 'TMP' ]
for var in import_env:
v = os.environ.get(var)
if v:
@@ -291,12 +291,12 @@ def generate(env):
# environment's ENV. This is a potential slippery slope, because we
# *don't* want to make builds dependent on the user's environment by
- # default. We're doing this for SYSTEMROOT, though, because it's
+ # default. We're doing this for SystemRoot, though, because it's
# needed for anything that uses sockets, and seldom changes, and
@@ -291,12 +291,12 @@ def generate(env):
# needed for anything that uses sockets, and seldom changes, and
- # for SYSTEMDRIVE because it's related.
+ # for SystemDrive because it's related.
#
# Weigh the impact carefully before adding other variables to this list.